@@ -41,14 +41,13 @@
 #include "layers/selections/image/kpRectangularImageSelection.h"
 #include "layers/selections/text/kpTextSelection.h"
 
-#include <math.h>
 
-#include <qapplication.h>
-#include <qpoint.h>
-#include <qpolygon.h>
-#include <qrect.h>
-#include <qsize.h>
-#include <qmatrix.h>
+#include <QApplication>
+#include <QPoint>
+#include <QPolygon>
+#include <QRect>
+#include <QSize>
+#include <QTransform>
 
 #include "kpLogCategories.h"
 
@@ -98,15 +97,19 @@ QString kpTransformResizeScaleCommand::name () const
     {
         if (m_actOnTextSelection)
         {
-            if (m_type == Resize)
+            if (m_type == Resize) {
                 return i18n ("Text: Resize Box");
+            }
         }
         else
         {
-            if (m_type == Scale)
+            if (m_type == Scale) {
                 return i18n ("Selection: Scale");
-            else if (m_type == SmoothScale)
+            }
+
+            if (m_type == SmoothScale) {
                 return i18n ("Selection: Smooth Scale");
+            }
         }
     }
     else
@@ -164,7 +167,7 @@ void kpTransformResizeScaleCommand::setNewHeight (int height)
 // public
 QSize kpTransformResizeScaleCommand::newSize () const
 {
-    return QSize (newWidth (), newHeight ());
+    return  {newWidth (), newHeight ()};
 }
 
 // public virtual
@@ -190,8 +193,7 @@ bool kpTransformResizeScaleCommand::scaleSelectionWithImage () const
 void kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument ()
 {
 #if DEBUG_KP_TOOL_RESIZE_SCALE_COMMAND
-    qCDebug(kpLogCommands) << "kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument"
-               << endl;
+    qCDebug(kpLogCommands) << "kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument";
 #endif
 
     Q_ASSERT (m_oldSelectionPtr);
@@ -201,8 +203,8 @@ void kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument ()
     const double horizScale = double (m_newWidth) / double (m_oldWidth);
     const double vertScale = double (m_newHeight) / double (m_oldHeight);
 
-    const int newX = (int) (m_oldSelectionPtr->x () * horizScale);
-    const int newY = (int) (m_oldSelectionPtr->y () * vertScale);
+    const int newX = static_cast<int> (m_oldSelectionPtr->x () * horizScale);
+    const int newY = static_cast<int> (m_oldSelectionPtr->y () * vertScale);
 
 
     QPolygon currentPoints = m_oldSelectionPtr->calculatePoints ();
@@ -211,7 +213,7 @@ void kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument ()
 
     // TODO: refactor into kpPixmapFX
     // TODO: Can we get to size 0x0 accidently?
-    QMatrix scaleMatrix;
+    QTransform scaleMatrix;
     scaleMatrix.scale (horizScale, vertScale);
     currentPoints = scaleMatrix.map (currentPoints);
 
@@ -219,10 +221,9 @@ void kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument ()
         -currentPoints.boundingRect ().x () + newX,
         -currentPoints.boundingRect ().y () + newY);
 
-    kpAbstractImageSelection *imageSel =
-        dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr);
-    kpTextSelection *textSel =
-        dynamic_cast <kpTextSelection *> (m_oldSelectionPtr);
+    auto *imageSel = dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr);
+    auto *textSel = dynamic_cast <kpTextSelection *> (m_oldSelectionPtr);
+
     if (imageSel)
     {
         document ()->setSelection (
@@ -236,8 +237,9 @@ void kpTransformResizeScaleCommand::scaleSelectionRegionWithDocument ()
                 textSel->textLines (),
                 textSel->textStyle ()));
     }
-    else
+    else {
         Q_ASSERT (!"Unknown selection type");
+    }
 
 
     environ ()->somethingBelowTheCursorChanged ();
@@ -253,8 +255,7 @@ void kpTransformResizeScaleCommand::execute ()
                << " oldWidth=" << m_oldWidth
                << " oldHeight=" << m_oldHeight
                << " newWidth=" << m_newWidth
-               << " newHeight=" << m_newHeight
-               << endl;
+               << " newHeight=" << m_newHeight;
 #endif
 
     if (m_oldWidth == m_newWidth && m_oldHeight == m_newHeight)
@@ -264,8 +265,9 @@ void kpTransformResizeScaleCommand::execute ()
     {
         if (m_actOnSelection)
         {
-            if (!m_actOnTextSelection)
+            if (!m_actOnTextSelection) {
                 Q_ASSERT (!"kpTransformResizeScaleCommand::execute() resizing sel doesn't make sense");
+            }
 
             QApplication::setOverrideCursor (Qt::WaitCursor);
 
@@ -313,8 +315,9 @@ void kpTransformResizeScaleCommand::execute ()
 
         kpImage oldImage = document ()->image (m_actOnSelection);
 
-        if (!m_isLosslessScale)
+        if (!m_isLosslessScale) {
             m_oldImage = oldImage;
+        }
 
         kpImage newImage = kpPixmapFX::scale (oldImage, m_newWidth, m_newHeight,
                                                m_type == SmoothScale);
@@ -329,12 +332,14 @@ void kpTransformResizeScaleCommand::execute ()
 
         if (m_actOnSelection)
         {
-            if (m_actOnTextSelection)
+            if (m_actOnTextSelection) {
                 Q_ASSERT (!"kpTransformResizeScaleCommand::execute() scaling text sel doesn't make sense");
+            }
 
             Q_ASSERT (m_oldSelectionPtr);
-            if ( !m_oldSelectionPtr )  // make coverity happy
-              return;
+            if ( !m_oldSelectionPtr ) {  // make coverity happy
+                return;
+            }
 
             QRect newRect = QRect (m_oldSelectionPtr->x (), m_oldSelectionPtr->y (),
                                    newImage.width (), newImage.height ());
@@ -344,7 +349,7 @@ void kpTransformResizeScaleCommand::execute ()
             Q_ASSERT (dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr));
             document ()->setSelection (
                 kpRectangularImageSelection (newRect, newImage,
-                    static_cast <kpAbstractImageSelection *> (m_oldSelectionPtr)
+                    dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr)
                         ->transparency ()));
 
             environ ()->somethingBelowTheCursorChanged ();
@@ -369,11 +374,12 @@ void kpTransformResizeScaleCommand::unexecute ()
 {
 #if DEBUG_KP_TOOL_RESIZE_SCALE_COMMAND
     qCDebug(kpLogCommands) << "kpTransformResizeScaleCommand::unexecute() type="
-               << m_type << endl;
+               << m_type;
 #endif
 
-    if (m_oldWidth == m_newWidth && m_oldHeight == m_newHeight)
+    if (m_oldWidth == m_newWidth && m_oldHeight == m_newHeight) {
         return;
+    }
 
     kpDocument *doc = document ();
     Q_ASSERT (doc);
@@ -382,8 +388,9 @@ void kpTransformResizeScaleCommand::unexecute ()
     {
         if (m_actOnSelection)
         {
-            if (!m_actOnTextSelection)
+            if (!m_actOnTextSelection) {
                 Q_ASSERT (!"kpTransformResizeScaleCommand::unexecute() resizing sel doesn't make sense");
+            }
 
             QApplication::setOverrideCursor (Qt::WaitCursor);
 
@@ -436,21 +443,22 @@ void kpTransformResizeScaleCommand::unexecute ()
 
         kpImage oldImage;
 
-        if (!m_isLosslessScale)
+        if (!m_isLosslessScale) {
             oldImage = m_oldImage;
-        else
+        } else {
             oldImage = kpPixmapFX::scale (doc->image (m_actOnSelection),
                                           m_oldWidth, m_oldHeight);
+        }
 
 
         if (m_actOnSelection)
         {
-            if (m_actOnTextSelection)
+            if (m_actOnTextSelection) {
                 Q_ASSERT (!"kpTransformResizeScaleCommand::unexecute() scaling text sel doesn't make sense");
+            }
 
             Q_ASSERT (dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr));
-            kpAbstractImageSelection *oldImageSel =
-                static_cast <kpAbstractImageSelection *> (m_oldSelectionPtr);
+            auto *oldImageSel = dynamic_cast <kpAbstractImageSelection *> (m_oldSelectionPtr);
 
             kpAbstractImageSelection *oldSelection = oldImageSel->clone ();
             oldSelection->setBaseImage (oldImage);
