@@ -63,7 +63,7 @@ Q_OBJECT
 
 public:
     kpCommandHistory (bool doReadConfig, kpMainWindow *mainWindow);
-    virtual ~kpCommandHistory ();
+    ~kpCommandHistory () override;
 
 public:
     // Same as addCommand(), except that this has a more desirable behavior
@@ -94,8 +94,8 @@ public:
         bool execute = true);
 
 public slots:
-    void undo () Q_DECL_OVERRIDE;
-    void redo () Q_DECL_OVERRIDE;
+    void undo () override;
+    void redo () override;
 
 protected:
     kpMainWindow *m_mainWindow;
