@@ -88,7 +88,7 @@ kpColorCollection::installedCollections()
 
   QStringList paths = QStandardPaths::locateAll(QStandardPaths::GenericConfigLocation, "colors",
                                                 QStandardPaths::LocateDirectory);
-  foreach (const QString &path, paths) {
+  for (const auto &path : paths) {
     paletteList.append(QDir(path).entryList(QStringList(), QDir::Files));
   }
 
@@ -269,7 +269,7 @@ static void SaveToFile (kpColorCollectionPrivate *d, QIODevice *device)
 
    str << "KDE RGB Palette\n";
    str << description << "\n";
-   foreach (const ColorNode &node, d->colorList)
+   for (const auto &node : d->colorList)
    {
        // Added for KolourPaint.
        if(!node.color.isValid ())
@@ -317,7 +317,7 @@ kpColorCollection::saveAs(const QUrl &url, bool showOverwritePrompt,
 
             #if DEBUG_KP_COLOR_COLLECTION
                 qCDebug(kpLogMisc) << "\treturning false because could not open QSaveFile"
-                          << " error=" << atomicFileWriter.error () << endl;
+                          << " error=" << atomicFileWriter.error ();
             #endif
                 ::CouldNotSaveDialog (url, parent);
                 return false;
