@@ -30,7 +30,7 @@
 #include "kpMainWindowPrivate.h"
 
 #include <QActionGroup>
-#include <qlist.h>
+#include <QList>
 
 #include <kactioncollection.h>
 #include <KSharedConfig>
@@ -75,8 +75,9 @@
 // private
 kpToolSelectionEnvironment *kpMainWindow::toolSelectionEnvironment ()
 {
-    if (!d->toolSelectionEnvironment)
+    if (!d->toolSelectionEnvironment) {
         d->toolSelectionEnvironment = new kpToolSelectionEnvironment (this);
+    }
 
     return d->toolSelectionEnvironment;
 }
@@ -133,26 +134,26 @@ void kpMainWindow::setupToolActions ()
     d->actionPrevToolOptionGroup1 = ac->addAction ("prev_tool_option_group_1");
     d->actionPrevToolOptionGroup1->setText (i18n ("Previous Tool Option (Group #1)"));
     ac->setDefaultShortcuts (d->actionPrevToolOptionGroup1, kpTool::shortcutForKey (Qt::Key_1));
-    connect (d->actionPrevToolOptionGroup1, SIGNAL (triggered(bool)),
-        SLOT (slotActionPrevToolOptionGroup1()));
+    connect (d->actionPrevToolOptionGroup1, &QAction::triggered,
+             this, &kpMainWindow::slotActionPrevToolOptionGroup1);
 
     d->actionNextToolOptionGroup1 = ac->addAction ("next_tool_option_group_1");
     d->actionNextToolOptionGroup1->setText (i18n ("Next Tool Option (Group #1)"));
     ac->setDefaultShortcuts (d->actionNextToolOptionGroup1, kpTool::shortcutForKey (Qt::Key_2));
-    connect (d->actionNextToolOptionGroup1, SIGNAL (triggered(bool)),
-        SLOT (slotActionNextToolOptionGroup1()));
+    connect (d->actionNextToolOptionGroup1, &QAction::triggered,
+             this, &kpMainWindow::slotActionNextToolOptionGroup1);
 
     d->actionPrevToolOptionGroup2 = ac->addAction ("prev_tool_option_group_2");
     d->actionPrevToolOptionGroup2->setText (i18n ("Previous Tool Option (Group #2)"));
     ac->setDefaultShortcuts (d->actionPrevToolOptionGroup2, kpTool::shortcutForKey (Qt::Key_3));
-    connect (d->actionPrevToolOptionGroup2, SIGNAL (triggered(bool)),
-        SLOT (slotActionPrevToolOptionGroup2()));
+    connect (d->actionPrevToolOptionGroup2, &QAction::triggered,
+             this, &kpMainWindow::slotActionPrevToolOptionGroup2);
 
     d->actionNextToolOptionGroup2 = ac->addAction ("next_tool_option_group_2");
     d->actionNextToolOptionGroup2->setText (i18n ("Next Tool Option (Group #2)"));
     ac->setDefaultShortcuts (d->actionNextToolOptionGroup2, kpTool::shortcutForKey (Qt::Key_4));
-    connect (d->actionNextToolOptionGroup2, SIGNAL (triggered(bool)),
-        SLOT (slotActionNextToolOptionGroup2()));
+    connect (d->actionNextToolOptionGroup2, &QAction::triggered,
+             this, &kpMainWindow::slotActionNextToolOptionGroup2);
 
 
     //
@@ -162,13 +163,13 @@ void kpMainWindow::setupToolActions ()
 
     d->actionDrawOpaque = ac->add <KToggleAction> ("image_draw_opaque");
     d->actionDrawOpaque->setText (i18n ("&Draw Opaque"));
-    connect (d->actionDrawOpaque, SIGNAL (triggered(bool)),
-        SLOT (slotActionDrawOpaqueToggled()));
+    connect (d->actionDrawOpaque, &QAction::triggered,
+             this, &kpMainWindow::slotActionDrawOpaqueToggled);
 
     d->actionDrawColorSimilarity = ac->addAction ("image_draw_color_similarity");
     d->actionDrawColorSimilarity->setText (i18n ("Draw With Color Similarity..."));
-    connect (d->actionDrawColorSimilarity, SIGNAL (triggered(bool)),
-        SLOT (slotActionDrawColorSimilarity()));
+    connect (d->actionDrawColorSimilarity, &QAction::triggered,
+             this, &kpMainWindow::slotActionDrawColorSimilarity);
 }
 
 //---------------------------------------------------------------------
@@ -179,18 +180,21 @@ void kpMainWindow::createToolBox ()
     d->toolToolBar = new kpToolToolBar(QLatin1String("Tool Box"), 2/*columns/rows*/, this);
     d->toolToolBar->setWindowTitle(i18n("Tool Box"));
 
-    connect (d->toolToolBar, SIGNAL (sigToolSelected(kpTool*)),
-             this, SLOT (slotToolSelected(kpTool*)));
-    connect (d->toolToolBar, SIGNAL (toolWidgetOptionSelected()),
-             this, SLOT (updateToolOptionPrevNextActionsEnabled()));
+    connect (d->toolToolBar, &kpToolToolBar::sigToolSelected,
+             this, &kpMainWindow::slotToolSelected);
+
+    connect (d->toolToolBar, &kpToolToolBar::toolWidgetOptionSelected,
+             this, &kpMainWindow::updateToolOptionPrevNextActionsEnabled);
+
+    connect (d->toolToolBar->toolWidgetOpaqueOrTransparent(),
+             &kpToolWidgetOpaqueOrTransparent::isOpaqueChanged,
+             this, &kpMainWindow::updateActionDrawOpaqueChecked);
 
-    connect (d->toolToolBar->toolWidgetOpaqueOrTransparent (),
-             SIGNAL (isOpaqueChanged(bool)),
-             SLOT (updateActionDrawOpaqueChecked()));
     updateActionDrawOpaqueChecked ();
 
-    foreach (kpTool *tool, d->tools)
+    for (auto *tool : d->tools) {
       d->toolToolBar->registerTool(tool);
+    }
 
     // (from config file)
     readLastTool ();
@@ -213,14 +217,17 @@ void kpMainWindow::enableToolsDocumentActions (bool enable)
 
         // select tool for enabled Tool Box
 
-        if (previousTool)
+        if (previousTool) {
             d->toolToolBar->selectPreviousTool ();
+        }
         else
         {
-            if (d->lastToolNumber >= 0 && d->lastToolNumber < (int) d->tools.count ())
+            if (d->lastToolNumber >= 0 && d->lastToolNumber < d->tools.count ()) {
                 d->toolToolBar->selectTool (d->tools.at (d->lastToolNumber));
-            else
+            }
+            else {
                 d->toolToolBar->selectTool (d->toolPen);
+            }
         }
     }
     else if (!enable && d->toolToolBar->isEnabled ())
@@ -233,11 +240,12 @@ void kpMainWindow::enableToolsDocumentActions (bool enable)
     d->toolToolBar->setEnabled (enable);
 
 
-    foreach (kpTool *tool, d->tools)
+    for (auto *tool : d->tools)
     {
       kpToolAction *action = tool->action();
-      if (!enable && action->isChecked())
+      if (!enable && action->isChecked()) {
           action->setChecked(false);
+      }
 
       action->setEnabled(enable);
     }
@@ -301,9 +309,8 @@ void kpMainWindow::updateActionDrawOpaqueEnabled ()
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\tenable=" << enable
-              << " tool=" << (tool () ? tool ()->objectName () : 0)
-              << " (is selection=" << toolIsASelectionTool () << ")"
-              << endl;
+              << " tool=" << (tool () ? tool ()->objectName () : nullptr)
+              << " (is selection=" << toolIsASelectionTool () << ")";
 #endif
 
     d->actionDrawOpaque->setEnabled (enable && toolIsASelectionTool ());
@@ -314,8 +321,9 @@ void kpMainWindow::updateActionDrawOpaqueEnabled ()
 // public
 QActionGroup *kpMainWindow::toolsActionGroup ()
 {
-    if (!d->toolsActionGroup)
+    if (!d->toolsActionGroup) {
         d->toolsActionGroup = new QActionGroup (this);
+    }
 
     return d->toolsActionGroup;
 }
@@ -364,8 +372,9 @@ bool kpMainWindow::toolIsTextTool () const
 // private
 void kpMainWindow::toolEndShape ()
 {
-    if (toolHasBegunShape ())
+    if (toolHasBegunShape ()) {
         tool ()->endShapeInternal ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -386,9 +395,8 @@ void kpMainWindow::setImageSelectionTransparency (const kpImageSelectionTranspar
 {
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::setImageSelectionTransparency() isOpaque=" << transparency.isOpaque ()
-               << " color=" << (transparency.transparentColor ().isValid () ? (int *) transparency.transparentColor ().toQRgb () : 0)
-               << " forceColorChange=" << forceColorChange
-               << endl;
+               << " color=" << (transparency.transparentColor ().isValid () ? (int *) transparency.transparentColor ().toQRgb () : nullptr)
+               << " forceColorChange=" << forceColorChange;
 #endif
 
     kpToolWidgetOpaqueOrTransparent *oot = d->toolToolBar->toolWidgetOpaqueOrTransparent ();
@@ -427,55 +435,73 @@ void kpMainWindow::slotToolSelected (kpTool *tool)
 
     if (previousTool)
     {
-        disconnect (previousTool, SIGNAL (movedAndAboutToDraw(QPoint,QPoint,int,bool*)),
-                    this, SLOT (slotDragScroll(QPoint,QPoint,int,bool*)));
-        disconnect (previousTool, SIGNAL (endedDraw(QPoint)),
-                    this, SLOT (slotEndDragScroll()));
-        disconnect (previousTool, SIGNAL (cancelledShape(QPoint)),
-                    this, SLOT (slotEndDragScroll()));
+        disconnect (previousTool, &kpTool::movedAndAboutToDraw,
+                    this, &kpMainWindow::slotDragScroll);
 
-        disconnect (previousTool, SIGNAL (userMessageChanged(QString)),
-                    this, SLOT (recalculateStatusBarMessage()));
-        disconnect (previousTool, SIGNAL (userShapePointsChanged(QPoint,QPoint)),
-                    this, SLOT (recalculateStatusBarShape()));
-        disconnect (previousTool, SIGNAL (userShapeSizeChanged(QSize)),
-                    this, SLOT (recalculateStatusBarShape()));
+        disconnect (previousTool, &kpTool::endedDraw,
+                    this, &kpMainWindow::slotEndDragScroll);
 
-        disconnect (d->colorToolBar, SIGNAL (colorsSwapped(kpColor,kpColor)),
-                    previousTool, SLOT (slotColorsSwappedInternal(kpColor,kpColor)));
-        disconnect (d->colorToolBar, SIGNAL (foregroundColorChanged(kpColor)),
-                    previousTool, SLOT (slotForegroundColorChangedInternal(kpColor)));
-        disconnect (d->colorToolBar, SIGNAL (backgroundColorChanged(kpColor)),
-                    previousTool, SLOT (slotBackgroundColorChangedInternal(kpColor)));
-        disconnect (d->colorToolBar, SIGNAL (colorSimilarityChanged(double,int)),
-                    previousTool, SLOT (slotColorSimilarityChangedInternal(double,int)));
+        disconnect (previousTool, &kpTool::cancelledShape,
+                    this, &kpMainWindow::slotEndDragScroll);
+
+        disconnect (previousTool, &kpTool::userMessageChanged,
+                    this, &kpMainWindow::recalculateStatusBarMessage);
+
+        disconnect (previousTool, &kpTool::userShapePointsChanged,
+                    this, &kpMainWindow::recalculateStatusBarShape);
+
+        disconnect (previousTool, &kpTool::userShapeSizeChanged,
+                    this, &kpMainWindow::recalculateStatusBarShape);
+
+
+        disconnect (d->colorToolBar, &kpColorToolBar::colorsSwapped,
+                    previousTool, &kpTool::slotColorsSwappedInternal);
+
+        disconnect (d->colorToolBar, &kpColorToolBar::foregroundColorChanged,
+                    previousTool, &kpTool::slotForegroundColorChangedInternal);
+
+        disconnect (d->colorToolBar, &kpColorToolBar::backgroundColorChanged,
+                    previousTool, &kpTool::slotBackgroundColorChangedInternal);
+
+
+        disconnect (d->colorToolBar, &kpColorToolBar::colorSimilarityChanged,
+                    previousTool, &kpTool::slotColorSimilarityChangedInternal);
     }
 
     if (tool)
     {
-        connect (tool, SIGNAL (movedAndAboutToDraw(QPoint,QPoint,int,bool*)),
-                 this, SLOT (slotDragScroll(QPoint,QPoint,int,bool*)));
-        connect (tool, SIGNAL (endedDraw(QPoint)),
-                 this, SLOT (slotEndDragScroll()));
-        connect (tool, SIGNAL (cancelledShape(QPoint)),
-                 this, SLOT (slotEndDragScroll()));
+        connect (tool, &kpTool::movedAndAboutToDraw,
+                 this, &kpMainWindow::slotDragScroll);
+
+        connect (tool, &kpTool::endedDraw,
+                 this, &kpMainWindow::slotEndDragScroll);
+
+        connect (tool, &kpTool::cancelledShape,
+                 this, &kpMainWindow::slotEndDragScroll);
+
+        connect (tool, &kpTool::userMessageChanged,
+                 this, &kpMainWindow::recalculateStatusBarMessage);
+
+        connect (tool, &kpTool::userShapePointsChanged,
+                 this, &kpMainWindow::recalculateStatusBarShape);
+
+        connect (tool, &kpTool::userShapeSizeChanged,
+                 this, &kpMainWindow::recalculateStatusBarShape);
 
-        connect (tool, SIGNAL (userMessageChanged(QString)),
-                 this, SLOT (recalculateStatusBarMessage()));
-        connect (tool, SIGNAL (userShapePointsChanged(QPoint,QPoint)),
-                 this, SLOT (recalculateStatusBarShape()));
-        connect (tool, SIGNAL (userShapeSizeChanged(QSize)),
-                 this, SLOT (recalculateStatusBarShape()));
         recalculateStatusBar ();
 
-        connect (d->colorToolBar, SIGNAL (colorsSwapped(kpColor,kpColor)),
-                 tool, SLOT (slotColorsSwappedInternal(kpColor,kpColor)));
-        connect (d->colorToolBar, SIGNAL (foregroundColorChanged(kpColor)),
-                 tool, SLOT (slotForegroundColorChangedInternal(kpColor)));
-        connect (d->colorToolBar, SIGNAL (backgroundColorChanged(kpColor)),
-                 tool, SLOT (slotBackgroundColorChangedInternal(kpColor)));
-        connect (d->colorToolBar, SIGNAL (colorSimilarityChanged(double,int)),
-                 tool, SLOT (slotColorSimilarityChangedInternal(double,int)));
+
+        connect (d->colorToolBar, &kpColorToolBar::colorsSwapped,
+                 tool, &kpTool::slotColorsSwappedInternal);
+
+        connect (d->colorToolBar, &kpColorToolBar::foregroundColorChanged,
+                 tool, &kpTool::slotForegroundColorChangedInternal);
+
+        connect (d->colorToolBar, &kpColorToolBar::backgroundColorChanged,
+                 tool, &kpTool::slotBackgroundColorChangedInternal);
+
+        connect (d->colorToolBar, &kpColorToolBar::colorSimilarityChanged,
+                 tool, &kpTool::slotColorSimilarityChangedInternal);
 
 
         saveLastTool ();
@@ -505,8 +531,9 @@ int kpMainWindow::toolNumber () const
          it != d->tools.constEnd ();
          ++it)
     {
-        if (*it == tool ())
+        if (*it == tool ()) {
             return number;
+        }
 
         number++;
     }
@@ -520,8 +547,9 @@ int kpMainWindow::toolNumber () const
 void kpMainWindow::saveLastTool ()
 {
     int number = toolNumber ();
-    if (number < 0 || number >= (int) d->tools.count ())
+    if (number < 0 || number >= d->tools.count ()) {
         return;
+    }
 
 
     KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupTools);
@@ -552,18 +580,15 @@ bool kpMainWindow::slotDragScroll (const QPoint &docPoint,
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotDragScroll() maybeDragScrolling="
-               << maybeDragScrollingMainView ()
-               << endl;
+               << maybeDragScrollingMainView ();
 #endif
 
     if (maybeDragScrollingMainView ())
     {
         return d->scrollView->beginDragScroll(zoomLevel, scrolled);
     }
-    else
-    {
-        return false;
-    }
+
+    return false;
 }
 
 //---------------------------------------------------------------------
@@ -616,7 +641,7 @@ void kpMainWindow::slotEndedDocResize (const QSize &size)
     // Prevent statusbar updates
     d->docResizeToBeCompleted = true;
 
-    d->docResizeWidth = (size.width () > 0 ? size.width () : 1),
+    d->docResizeWidth = (size.width () > 0 ? size.width () : 1);
     d->docResizeHeight = (size.height () > 0 ? size.height () : 1);
 
     if (d->docResizeWidth == d->document->width () &&
@@ -673,14 +698,14 @@ void kpMainWindow::slotDocResizeMessageChanged (const QString &string)
 {
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::slotDocResizeMessageChanged(" << string
-               << ") docResizeToBeCompleted=" << d->docResizeToBeCompleted
-               << endl;
+               << ") docResizeToBeCompleted=" << d->docResizeToBeCompleted;
 #else
     (void) string;
 #endif
 
-    if (d->docResizeToBeCompleted)
+    if (d->docResizeToBeCompleted) {
         return;
+    }
 
     recalculateStatusBarMessage ();
 }
@@ -691,8 +716,9 @@ void kpMainWindow::slotDocResizeMessageChanged (const QString &string)
 // private slot
 void kpMainWindow::slotActionPrevToolOptionGroup1 ()
 {
-    if (!d->toolToolBar->shownToolWidget (0))
+    if (!d->toolToolBar->shownToolWidget (0)) {
         return;
+    }
 
     // We don't call toolEndShape() here because we want #23 in the file BUGS
     // to later work.
@@ -706,8 +732,9 @@ void kpMainWindow::slotActionPrevToolOptionGroup1 ()
 // private slot
 void kpMainWindow::slotActionNextToolOptionGroup1 ()
 {
-    if (!d->toolToolBar->shownToolWidget (0))
+    if (!d->toolToolBar->shownToolWidget (0)) {
         return;
+    }
 
     // We don't call toolEndShape() here because we want #23 in the file BUGS
     // to later work.
@@ -722,8 +749,9 @@ void kpMainWindow::slotActionNextToolOptionGroup1 ()
 // private slot
 void kpMainWindow::slotActionPrevToolOptionGroup2 ()
 {
-    if (!d->toolToolBar->shownToolWidget (1))
+    if (!d->toolToolBar->shownToolWidget (1)) {
         return;
+    }
 
     // We don't call toolEndShape() here because we want #23 in the file BUGS
     // to later work.
@@ -737,8 +765,9 @@ void kpMainWindow::slotActionPrevToolOptionGroup2 ()
 // private slot
 void kpMainWindow::slotActionNextToolOptionGroup2 ()
 {
-    if (!d->toolToolBar->shownToolWidget (1))
+    if (!d->toolToolBar->shownToolWidget (1)) {
         return;
+    }
 
     // We don't call toolEndShape() here because we want #23 in the file BUGS
     // to later work.
