@@ -30,11 +30,11 @@
 #define KP_TOOL_H
 
 
-#include <qobject.h>
-#include <qpoint.h>
-#include <qrect.h>
-#include <qsize.h>
-#include <qstring.h>
+#include <QObject>
+#include <QPoint>
+#include <QRect>
+#include <QSize>
+#include <QString>
 
 #include "kpDefs.h"
 #ifdef Q_OS_WIN
@@ -262,7 +262,7 @@ protected:
     double colorSimilarity () const;
     int processedColorSimilarity () const;
 
-protected slots:
+public slots:
     void slotColorsSwappedInternal (const kpColor &newForegroundColor,
                                     const kpColor &newBackgroundColor);
     void slotForegroundColorChangedInternal (const kpColor &color);
@@ -422,7 +422,6 @@ signals:
     void userShapePointsChanged (const QPoint &startPoint = KP_INVALID_POINT,
                                  const QPoint &endPoint = KP_INVALID_POINT);
     void userShapeSizeChanged (const QSize &size);
-    void userShapeSizeChanged (int width, int height);
 
 
 public:
