@@ -35,10 +35,10 @@
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
-#include <knuminput.h> // kdelibs4support
+#include "kpNumInput.h"
 
-#include <qgridlayout.h>
-#include <qlabel.h>
+#include <QGridLayout>
+#include <QLabel>
 #include <QSpinBox>
 
 
@@ -46,12 +46,11 @@ kpEffectBlurSharpenWidget::kpEffectBlurSharpenWidget (bool actOnSelection,
                                                       QWidget *parent)
     : kpEffectWidgetBase (actOnSelection, parent)
 {
-    QGridLayout *lay = new QGridLayout (this);
-    lay->setMargin (0);
+    auto *lay = new QGridLayout (this);
+    lay->setContentsMargins(0, 0, 0, 0);
 
-
-    QLabel *amountLabel = new QLabel (i18n ("&Amount:"), this);
-    m_amountInput = new KIntNumInput (this);
+    auto *amountLabel = new QLabel (i18n ("&Amount:"), this);
+    m_amountInput = new kpIntNumInput (this);
     m_amountInput->setRange (-kpEffectBlurSharpen::MaxStrength/*- for blur*/,
 			     +kpEffectBlurSharpen::MaxStrength/*+ for sharpen*/);
 
@@ -65,7 +64,7 @@ kpEffectBlurSharpenWidget::kpEffectBlurSharpenWidget (bool actOnSelection,
     // We do this by setting the label to every possible string it could
     // contain and fixing its height to the maximum seen size hint height.
 
-    int h = m_typeLabel->sizeHint ().height ();
+    auto h = m_typeLabel->sizeHint ().height ();
 #if DEBUG_KP_EFFECT_BLUR_SHARPEN
     qCDebug(kpLogWidgets) << "initial size hint height=" << h;
 #endif
@@ -102,16 +101,14 @@ kpEffectBlurSharpenWidget::kpEffectBlurSharpenWidget (bool actOnSelection,
     lay->setColumnStretch (1, 1);
 
 
-    connect (m_amountInput, SIGNAL (valueChanged (int)),
-             this, SIGNAL (settingsChangedDelayed ()));
+    connect (m_amountInput, &kpIntNumInput::valueChanged,
+             this, &kpEffectBlurSharpenWidget::settingsChangedDelayed);
 
-    connect (m_amountInput, SIGNAL (valueChanged (int)),
-             this, SLOT (slotUpdateTypeLabel ()));
+    connect (m_amountInput, &kpIntNumInput::valueChanged,
+             this, &kpEffectBlurSharpenWidget::slotUpdateTypeLabel);
 }
 
-kpEffectBlurSharpenWidget::~kpEffectBlurSharpenWidget ()
-{
-}
+kpEffectBlurSharpenWidget::~kpEffectBlurSharpenWidget () = default;
 
 
 // public virtual [base kpEffectWidgetBase]
@@ -151,14 +148,14 @@ void kpEffectBlurSharpenWidget::slotUpdateTypeLabel ()
 
 #if DEBUG_KP_EFFECT_BLUR_SHARPEN
     qCDebug(kpLogWidgets) << "kpEffectBlurSharpenWidget::slotUpdateTypeLabel() text="
-               << text << endl;
+               << text;
 #endif
     const int h = m_typeLabel->height ();
     m_typeLabel->setText (text);
     if (m_typeLabel->height () != h)
     {
         qCCritical(kpLogWidgets) << "Label changed height despite the hack in ctor:"
-                  << "was=" << h 
+                  << "was=" << h
                   << "now=" << m_typeLabel->height ();
     }
 }
@@ -167,12 +164,15 @@ void kpEffectBlurSharpenWidget::slotUpdateTypeLabel ()
 // protected
 kpEffectBlurSharpen::Type kpEffectBlurSharpenWidget::type () const
 {
-    if (m_amountInput->value () == 0)
+    if (m_amountInput->value () == 0) {
         return kpEffectBlurSharpen::None;
-    else if (m_amountInput->value () < 0)
+    }
+
+    if (m_amountInput->value () < 0) {
         return kpEffectBlurSharpen::Blur;
-    else
-        return kpEffectBlurSharpen::Sharpen;
+    }
+
+    return kpEffectBlurSharpen::Sharpen;
 }
 
 // protected
